package com.yanzhu.manage.service.impl;

import java.util.List;

import com.yanzhu.common.core.constant.SecurityConstants;
import com.yanzhu.common.core.domain.R;
import com.yanzhu.common.core.exception.ServiceException;
import com.yanzhu.common.core.utils.DateUtils;
import com.yanzhu.common.security.utils.SecurityUtils;
import com.yanzhu.manage.domain.ProDept;
import com.yanzhu.manage.domain.ProProjectInfoDepts;
import com.yanzhu.manage.domain.ProProjectInfoSetting;
import com.yanzhu.manage.mapper.ProProjectInfoDeptsMapper;
import com.yanzhu.manage.mapper.ProProjectInfoSettingMapper;
import com.yanzhu.system.api.RemoteDeptService;
import com.yanzhu.system.api.RemoteUserService;
import com.yanzhu.system.api.domain.SysDept;
import com.yanzhu.system.api.domain.SysUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yanzhu.manage.mapper.ProProjectInfoMapper;
import com.yanzhu.manage.domain.ProProjectInfo;
import com.yanzhu.manage.service.IProProjectInfoService;

/**
 * 项目信息Service业务层处理
 * 
 * @author JiangYuQi
 * @date 2024-08-25
 */
@Service
public class ProProjectInfoServiceImpl implements IProProjectInfoService 
{
    @Autowired
    private ProProjectInfoDeptsMapper deptsMapper;

    @Autowired
    private ProProjectInfoSettingMapper settingMapper;

    @Autowired
    private ProProjectInfoMapper proProjectInfoMapper;

    @Autowired
    private RemoteDeptService remoteDeptService;

    /**
     * 查询项目信息
     * 
     * @param id 项目信息主键
     * @return 项目信息
     */
    @Override
    public ProProjectInfo selectProProjectInfoById(Long id)
    {
        return proProjectInfoMapper.selectProProjectInfoById(id);
    }

    /**
     * 查询项目信息列表
     * 
     * @param proProjectInfo 项目信息
     * @return 项目信息
     */
    @Override
    public List<ProProjectInfo> selectProProjectInfoList(ProProjectInfo proProjectInfo)
    {
        SysUser sysUser = SecurityUtils.getLoginUser().getSysUser();
        if(!SecurityUtils.isAdmin(sysUser.getUserId())){
            proProjectInfo.setActiveComId(sysUser.getComId());
            if(!SecurityUtils.isGSAdmin()){
                proProjectInfo.setCurrentUserId(sysUser.getUserId());
            }
        }
        return proProjectInfoMapper.selectProProjectInfoList(proProjectInfo);
    }

    /**
     * 新增项目信息
     * 
     * @param proProjectInfo 项目信息
     * @return 结果
     */
    @Override
    public int insertProProjectInfo(ProProjectInfo proProjectInfo)
    {
        R<SysDept> deptResult = remoteDeptService.getDeptInfo(proProjectInfo.getDisDeptId(), SecurityConstants.INNER);
        SysDept sysDept = deptResult.getData();
        ProDept proDept = new ProDept();
        proDept.setParentId(proProjectInfo.getDisDeptId());
        proDept.setAncestors(sysDept.getAncestors()+","+proProjectInfo.getDisDeptId());
        proDept.setDeptName(proProjectInfo.getProjectName());
        proDept.setDeptShortName(proProjectInfo.getSimpleName());
        proDept.setDeptType("4");
        proDept.setOrderNum(100);
        proDept.setLeader(proProjectInfo.getProjectPerson());
        proDept.setPhone(proProjectInfo.getProjectPersonPhone());
        proDept.setCreateBy(SecurityUtils.getUsername());
        int res = proProjectInfoMapper.insertDept(proDept);
        if(res>0){
            proProjectInfo.setId(proDept.getDeptId());
            proProjectInfo.setComId(sysDept.getComId());
            proProjectInfo.setCreateTime(DateUtils.getNowDate());
            return proProjectInfoMapper.insertProProjectInfo(proProjectInfo);
        }else{
            throw new ServiceException("项目信息保存失败！！！");
        }
    }

    /**
     * 修改项目信息
     * 
     * @param proProjectInfo 项目信息
     * @return 结果
     */
    @Override
    public int updateProProjectInfo(ProProjectInfo proProjectInfo)
    {
        proProjectInfo.setUpdateTime(DateUtils.getNowDate());
        List<ProProjectInfoDepts> depts = proProjectInfo.getProjectDeptsList();
        if(depts!=null){
            depts.forEach(dept->{
                dept.setProjectId(proProjectInfo.getId());
                if(dept.getId()!=null){
                    deptsMapper.updateProProjectInfoDepts(dept);
                }else{
                    deptsMapper.insertProProjectInfoDepts(dept);
                }
            });
        }
        ProProjectInfoSetting setting = proProjectInfo.getSetting();
        if(setting!=null){
            setting.setProjectId(proProjectInfo.getId());
            if(setting.getId()!=null){
                settingMapper.updateProProjectInfoSetting(setting);
            }else{
                settingMapper.insertProProjectInfoSetting(setting);
            }
        }
        return proProjectInfoMapper.updateProProjectInfo(proProjectInfo);
    }

    /**
     * 批量删除项目信息
     * 
     * @param ids 需要删除的项目信息主键
     * @return 结果
     */
    @Override
    public int deleteProProjectInfoByIds(Long[] ids)
    {
        return proProjectInfoMapper.deleteProProjectInfoByIds(ids);
    }

    /**
     * 删除项目信息信息
     * 
     * @param id 项目信息主键
     * @return 结果
     */
    @Override
    public int deleteProProjectInfoById(Long id)
    {
        return proProjectInfoMapper.deleteProProjectInfoById(id);
    }
}
